@@ -1,21 +1,16 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -23,9 +18,9 @@ class CControllerImageUpdate extends CController {
 
 	protected function checkInput() {
 		$fields = [
-			'name'      => 'required | not_empty | db images.name',
-			'imageid'   => 'required | fatal | db images.imageid',
-			'imagetype' => 'required | fatal | db images.imagetype'
+			'name'      => 'required|not_empty|db images.name',
+			'imageid'   => 'required|fatal|db images.imageid',
+			'imagetype' => 'required|fatal|db images.imagetype'
 		];
 
 		$ret = $this->validateInput($fields);
@@ -58,13 +53,11 @@ class CControllerImageUpdate extends CController {
 			return false;
 		}
 
-		$images = API::Image()->get(['imageids' => (array) $this->getInput('imageid')]);
+		$images = API::Image()->get(['imageids' => $this->getInput('imageid')]);
 		if (!$images) {
 			return false;
 		}
 
-		$this->image = $images[0];
-
 		return true;
 	}
 
@@ -100,47 +93,59 @@ class CControllerImageUpdate extends CController {
 		$image = $this->uploadImage($error);
 
 		if ($error) {
-			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-				->setArgument('action', 'image.edit')
-				->setArgument('imagetype', $this->getInput('imagetype'))
-				->setArgument('imageid', $this->getInput('imageid'))
+			$response = new CControllerResponseRedirect(
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'image.edit')
+					->setArgument('imagetype', $this->getInput('imagetype'))
+					->setArgument('imageid', $this->getInput('imageid'))
 			);
 			error($error);
 			$response->setFormData($this->getInputAll());
 			CMessageHelper::setErrorTitle(_('Cannot update image'));
 
-			return $this->setResponse($response);
+			$this->setResponse($response);
+			return;
 		}
 
 		if ($this->hasInput('imageid')) {
-			$result = API::Image()->update([
+			$options = [
 				'imageid' => $this->getInput('imageid'),
-				'name'    => $this->getInput('name'),
-				'image'   => $image
-			]);
+				'name' => $this->getInput('name')
+			];
+
+			if ($image !== null) {
+				$options['image'] = $image;
+			}
+
+			$result = API::Image()->update($options);
 		}
 		else {
-			$result = API::Image()->create([
+			$options = [
 				'imagetype' => $this->getInput('imagetype'),
-				'name'      => $this->getInput('name'),
-				'image'     => $image
-			]);
+				'name' => $this->getInput('name')
+			];
+
+			if ($image !== null) {
+				$options['image'] = $image;
+			}
+
+			$result = API::Image()->create($options);
 		}
 
 		if ($result) {
-			add_audit(AUDIT_ACTION_UPDATE, AUDIT_RESOURCE_IMAGE, 'Image ['.$this->getInput('name').'] updated');
-
-			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-				->setArgument('action', 'image.list')
-				->setArgument('imagetype', $this->getInput('imagetype'))
+			$response = new CControllerResponseRedirect(
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'image.list')
+					->setArgument('imagetype', $this->getInput('imagetype'))
 			);
 			CMessageHelper::setSuccessTitle(_('Image updated'));
 		}
 		else {
-			$response = new CControllerResponseRedirect((new CUrl('zabbix.php'))
-				->setArgument('action', 'image.edit')
-				->setArgument('imagetype', $this->getInput('imagetype'))
-				->setArgument('imageid', $this->getInput('imageid'))
+			$response = new CControllerResponseRedirect(
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'image.edit')
+					->setArgument('imagetype', $this->getInput('imagetype'))
+					->setArgument('imageid', $this->getInput('imageid'))
 			);
 			$response->setFormData($this->getInputAll());
 			CMessageHelper::setErrorTitle(_('Cannot update image'));
