@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -25,6 +20,8 @@
  */
 
 $this->addJsFile('class.tagfilteritem.js');
+$this->addJsFile('items.js');
+$this->addJsFile('multilineinput.js');
 $this->includeJsFile('configuration.host.list.js.php');
 
 if ($data['uncheck']) {
@@ -44,7 +41,7 @@ $html_page = (new CHtmlPage())
 					->onClick(
 						'return PopUp("popup.import", {
 							rules_preset: "host", '.
-							CCsrfTokenHelper::CSRF_TOKEN_NAME.': "'. CCsrfTokenHelper::get('import').
+							CSRF_TOKEN_NAME.': "'.CCsrfTokenHelper::get('import').
 						'"}, {
 							dialogueid: "popup_import",
 							dialogue_class: "modal-popup-generic"
@@ -148,28 +145,47 @@ $filter = (new CFilter())
 						->addValue(_('Any'), ZBX_MONITORED_BY_ANY)
 						->addValue(_('Server'), ZBX_MONITORED_BY_SERVER)
 						->addValue(_('Proxy'), ZBX_MONITORED_BY_PROXY)
-						->setModern(true)
+						->addValue(_('Proxy group'), ZBX_MONITORED_BY_PROXY_GROUP)
+						->setModern()
 				)
 			])
 			->addItem([
-				new CLabel(_('Proxy'), 'filter_proxyids__ms'),
-				new CFormField(
+				(new CLabel(_('Proxies'), 'filter_proxyids__ms'))->addClass('js-filter-proxyids'),
+				(new CFormField(
 					(new CMultiSelect([
 						'name' => 'filter_proxyids[]',
 						'object_name' => 'proxies',
 						'data' => $data['proxies_ms'],
-						'disabled' => ($data['filter']['monitored_by'] != ZBX_MONITORED_BY_PROXY),
 						'popup' => [
 							'parameters' => [
 								'srctbl' => 'proxies',
 								'srcfld1' => 'proxyid',
-								'srcfld2' => 'host',
+								'srcfld2' => 'name',
 								'dstfrm' => 'zbx_filter',
 								'dstfld1' => 'filter_proxyids_'
 							]
 						]
 					]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
-				)
+				))->addClass('js-filter-proxyids')
+			])
+			->addItem([
+				(new CLabel(_('Proxy groups'), 'filter_proxy_groupids__ms'))->addClass('js-filter-proxy-groupids'),
+				(new CFormField(
+					(new CMultiSelect([
+						'name' => 'filter_proxy_groupids[]',
+						'object_name' => 'proxy_groups',
+						'data' => $data['proxy_groups_ms'],
+						'popup' => [
+							'parameters' => [
+								'srctbl' => 'proxy_groups',
+								'srcfld1' => 'proxy_groupid',
+								'srcfld2' => 'name',
+								'dstfrm' => 'zbx_filter',
+								'dstfld1' => 'filter_proxy_groupids_'
+							]
+						]
+					]))->setWidth(ZBX_TEXTAREA_MEDIUM_WIDTH)
+				))->addClass('js-filter-proxy-groupids')
 			])
 			->addItem([
 				new CLabel(_('Tags')),
@@ -187,8 +203,9 @@ $html_page->addItem($filter);
 // table hosts
 $form = (new CForm())->setName('hosts');
 $header_checkbox = (new CCheckBox('all_hosts'))->onClick("checkAll('".$form->getName()."', 'all_hosts', 'hostids');");
-$show_monitored_by = ($data['filter']['monitored_by'] == ZBX_MONITORED_BY_PROXY
-		|| $data['filter']['monitored_by'] == ZBX_MONITORED_BY_ANY);
+$show_monitored_by = $data['filter']['monitored_by'] == ZBX_MONITORED_BY_ANY
+	|| $data['filter']['monitored_by'] == ZBX_MONITORED_BY_PROXY
+	|| $data['filter']['monitored_by'] == ZBX_MONITORED_BY_PROXY_GROUP;
 $header_sortable_name = make_sorting_header(_('Name'), 'name', $data['sortField'], $data['sortOrder'],
 	$action_url->getUrl()
 );
@@ -213,7 +230,8 @@ $table = (new CTableInfo())
 		_('Agent encryption'),
 		_('Info'),
 		_('Tags')
-	]);
+	])
+	->setPageNavigation($data['paging']);
 
 $current_time = time();
 $csrf_token_massupdate = CCsrfTokenHelper::get('host');
@@ -331,13 +349,11 @@ foreach ($data['hosts'] as $host) {
 		}
 
 		if (array_key_exists($template['templateid'], $data['writable_templates'])
-				&& $data['allowed_ui_conf_templates']) {
+				&& $data['user']['can_edit_templates']) {
 			$caption = [
-				(new CLink($template['name'],
-					(new CUrl('templates.php'))
-						->setArgument('form', 'update')
-						->setArgument('templateid', $template['templateid'])
-				))
+				(new CLink($template['name']))
+					->addClass('js-edit-template')
+					->setAttribute('data-templateid', $template['templateid'])
 					->addClass(ZBX_STYLE_LINK_ALT)
 					->addClass(ZBX_STYLE_GREY)
 			];
@@ -357,12 +373,10 @@ foreach ($data['hosts'] as $host) {
 
 			foreach ($parent_templates as $parent_template) {
 				if (array_key_exists($parent_template['templateid'], $data['writable_templates'])
-						&& $data['allowed_ui_conf_templates']) {
-					$caption[] = (new CLink($parent_template['name'],
-						(new CUrl('templates.php'))
-							->setArgument('form', 'update')
-							->setArgument('templateid', $parent_template['templateid'])
-					))
+						&& $data['user']['can_edit_templates']) {
+					$caption[] = (new CLink($parent_template['name']))
+						->addClass('js-edit-template')
+						->setAttribute('data-templateid', $parent_template['templateid'])
 						->addClass(ZBX_STYLE_LINK_ALT)
 						->addClass(ZBX_STYLE_GREY);
 				}
@@ -386,8 +400,15 @@ foreach ($data['hosts'] as $host) {
 
 	$info_icons = [];
 
-	if ($host['flags'] == ZBX_FLAG_DISCOVERY_CREATED && $host['hostDiscovery']['ts_delete'] != 0) {
-		$info_icons[] = getHostLifetimeIndicator($current_time, $host['hostDiscovery']['ts_delete']);
+	$disable_source = $host['status'] == HOST_STATUS_NOT_MONITORED && $host['hostDiscovery']
+		? $host['hostDiscovery']['disable_source']
+		: '';
+
+	if ($host['flags'] == ZBX_FLAG_DISCOVERY_CREATED && $host['hostDiscovery']['status'] == ZBX_LLD_STATUS_LOST) {
+		$info_icons[] = getLldLostEntityIndicator($current_time, $host['hostDiscovery']['ts_delete'],
+			$host['hostDiscovery']['ts_disable'], $disable_source, $host['status'] == HOST_STATUS_NOT_MONITORED,
+			_('host')
+		);
 	}
 
 	if ($host['tls_connect'] == HOST_ENCRYPTION_NONE
@@ -441,26 +462,56 @@ foreach ($data['hosts'] as $host) {
 	$monitored_by = null;
 
 	if ($show_monitored_by) {
-		$monitored_by = ($host['proxy_hostid'] != 0)
-			? $data['proxies'][$host['proxy_hostid']]['host']
-			: '';
+		if ($host['monitored_by'] == ZBX_MONITORED_BY_PROXY) {
+			$monitored_by = $data['user']['can_edit_proxies']
+				? (new CLink($data['proxies'][$host['proxyid']]['name']))
+					->addClass('js-edit-proxy')
+					->setAttribute('data-proxyid', $host['proxyid'])
+				: $data['proxies'][$host['proxyid']]['name'];
+		}
+		elseif ($host['monitored_by'] == ZBX_MONITORED_BY_PROXY_GROUP) {
+			$monitored_by = $data['user']['can_edit_proxy_groups']
+				? (new CLink($data['proxy_groups'][$host['proxy_groupid']]['name']))
+					->addClass(ZBX_STYLE_LINK_ALT)
+					->addClass(ZBX_STYLE_GREY)
+					->addClass('js-edit-proxy-group')
+					->setAttribute('data-proxy_groupid', $host['proxy_groupid'])
+				: $data['proxy_groups'][$host['proxy_groupid']]['name'];
+
+			if ($host['assigned_proxyid'] != 0) {
+				$monitored_by = [$monitored_by];
+				$monitored_by[] = NAME_DELIMITER;
+				$monitored_by[] = $data['user']['can_edit_proxies']
+					? (new CLink($data['proxies'][$host['assigned_proxyid']]['name']))
+						->addClass('js-edit-proxy')
+						->setAttribute('data-proxyid', $host['assigned_proxyid'])
+					: $data['proxies'][$host['assigned_proxyid']]['name'];
+			}
+		}
+		else {
+			$monitored_by = '';
+		}
 	}
 
+	$disabled_by_lld = $disable_source == ZBX_DISABLE_SOURCE_LLD;
+
 	$table->addRow([
 		new CCheckBox('hostids['.$host['hostid'].']', $host['hostid']),
 		(new CCol($description))->addClass(ZBX_STYLE_NOWRAP),
 		[
 			new CLink(_('Items'),
-				(new CUrl('items.php'))
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'item.list')
+					->setArgument('context', 'host')
 					->setArgument('filter_set', '1')
 					->setArgument('filter_hostids', [$host['hostid']])
-					->setArgument('context', 'host')
 			),
 			CViewHelper::showNum($host['items'])
 		],
 		[
 			new CLink(_('Triggers'),
-				(new CUrl('triggers.php'))
+				(new CUrl('zabbix.php'))
+					->setArgument('action', 'trigger.list')
 					->setArgument('filter_set', '1')
 					->setArgument('filter_hostids', [$host['hostid']])
 					->setArgument('context', 'host')
@@ -497,8 +548,11 @@ foreach ($data['hosts'] as $host) {
 		getHostInterface($interface),
 		$monitored_by,
 		$hostTemplates,
-		$toggle_status_link,
-		getHostAvailabilityTable($host['interfaces']),
+		[
+			$toggle_status_link,
+			$disabled_by_lld ? makeDescriptionIcon(_('Disabled automatically by an LLD rule.')) : null
+		],
+		getHostAvailabilityTable($host['interfaces'], $host['has_passive_checks']),
 		$encryption,
 		makeInformationList($info_icons),
 		$data['tags'][$host['hostid']]
@@ -507,7 +561,7 @@ foreach ($data['hosts'] as $host) {
 
 $status_toggle_url =  (new CUrl('zabbix.php'))
 	->setArgument('action', 'popup.massupdate.host')
-	->setArgument(CCsrfTokenHelper::CSRF_TOKEN_NAME, $csrf_token_massupdate)
+	->setArgument(CSRF_TOKEN_NAME, $csrf_token_massupdate)
 	->setArgument('visible[status]', 1)
 	->setArgument('update', 1)
 	->setArgument('backurl',
@@ -519,18 +573,19 @@ $status_toggle_url =  (new CUrl('zabbix.php'))
 
 $form->addItem([
 	$table,
-	$data['paging'],
 	new CActionButtonList('action', 'hostids', [
 		'enable-hosts' => [
 			'name' => _('Enable'),
-			'confirm' => _('Enable selected hosts?'),
+			'confirm_singular' => _('Enable selected host?'),
+			'confirm_plural' => _('Enable selected hosts?'),
 			'redirect' => $status_toggle_url
 				->setArgument('status', HOST_STATUS_MONITORED)
 				->getUrl()
 		],
 		'disable-hosts' => [
 			'name' => _('Disable'),
-			'confirm' => _('Disable selected hosts?'),
+			'confirm_singular' => _('Disable selected host?'),
+			'confirm_plural' => _('Disable selected hosts?'),
 			'redirect' => $status_toggle_url
 				->setArgument('status', HOST_STATUS_NOT_MONITORED)
 				->getUrl()
@@ -542,25 +597,24 @@ $form->addItem([
 			)
 		],
 		'popup.massupdate.host' => [
-			'content' => (new CButton('', _('Mass update')))
+			'content' => (new CSimpleButton(_('Mass update')))
+				->addClass(ZBX_STYLE_BTN_ALT)
+				->addClass('js-no-chkbxrange')
 				->onClick(
 					"openMassupdatePopup('popup.massupdate.host', {".
-						CCsrfTokenHelper::CSRF_TOKEN_NAME.": '".$csrf_token_massupdate.
+						CSRF_TOKEN_NAME.": '".$csrf_token_massupdate.
 					"'}, {
 						dialogue_class: 'modal-popup-static',
 						trigger_element: this
 					});"
 				)
-				->addClass(ZBX_STYLE_BTN_ALT)
-				->addClass('no-chkbxrange')
 		],
 		'host.massdelete' => [
 			'content' => (new CSimpleButton(_('Delete')))
-				->setAttribute('confirm', _('Delete selected hosts?'))
 				->onClick('view.massDeleteHosts(this);')
 				->addClass(ZBX_STYLE_BTN_ALT)
-				->addClass('no-chkbxrange')
-				->removeAttribute('id')
+				->addClass('js-no-chkbxrange')
+				->removeId()
 		]
 	], 'hosts')
 ]);
