@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
 ** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -28,11 +23,97 @@
 	const view = {
 		form: null,
 
-		init({form_name, host_interfaces, host_is_discovered}) {
+		init({form_name, host_interfaces, proxy_groupid, host_is_discovered}) {
 			this.form = document.getElementById(form_name);
 			this.form.addEventListener('submit', this.events.submit);
+			this.form_name = form_name;
 
-			host_edit.init({form_name, host_interfaces, host_is_discovered});
+			host_edit.init({form_name, host_interfaces, proxy_groupid, host_is_discovered});
+			this.initEvents();
+		},
+
+		initEvents() {
+			this.form.addEventListener('click', (e) => {
+				const target = e.target;
+
+				if (target.classList.contains('js-edit-linked-template')) {
+					this.editTemplate({templateid: e.target.dataset.templateid});
+				}
+				else if (target.classList.contains('js-edit-proxy')) {
+					this.editProxy(e.target.dataset.proxyid);
+				}
+				else if (target.classList.contains('js-update-item')) {
+					this.editItem(target, target.dataset);
+				}
+			});
+		},
+
+		editItem(target, data) {
+			const overlay = PopUp('item.edit', target.dataset, {
+				dialogueid: 'item-edit',
+				dialogue_class: 'modal-popup-large',
+				trigger_element: target,
+				prevent_navigation: true
+			});
+
+			overlay.$dialogue[0].addEventListener('dialogue.submit', e => {
+					const data = e.detail;
+
+					if ('success' in data) {
+						postMessageOk(data.success.title);
+
+						if ('messages' in data.success) {
+							postMessageDetails('success', data.success.messages);
+						}
+					}
+
+					location.href = location.href;
+				}, {once: true}
+			);
+		},
+
+		editTemplate(parameters) {
+			const overlay = PopUp('template.edit', parameters, {
+				dialogueid: 'templates-form',
+				dialogue_class: 'modal-popup-large',
+				prevent_navigation: true
+			});
+
+			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => {
+				postMessageOk(e.detail.title);
+
+				if ('success' in e.detail) {
+					postMessageOk(e.detail.success.title);
+
+					if ('messages' in e.detail.success) {
+						postMessageDetails('success', e.detail.success.messages);
+					}
+				}
+
+				location.href = location.href;
+			});
+		},
+
+		editProxy(proxyid) {
+			const overlay = PopUp('popup.proxy.edit', {proxyid}, {
+				dialogueid: 'proxy_edit',
+				dialogue_class: 'modal-popup-static',
+				prevent_navigation: true
+			});
+
+			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => {
+				postMessageOk(e.detail.title);
+
+				if ('success' in e.detail) {
+					postMessageOk(e.detail.success.title);
+
+					if ('messages' in e.detail.success) {
+						postMessageDetails('success', e.detail.success.messages);
+					}
+				}
+
+				location.href = location.href;
+			});
 		},
 
 		submit(button) {
@@ -79,16 +160,6 @@
 			post(url.getUrl(), fields);
 		},
 
-		fullClone() {
-			const url = new Curl('');
-			url.setArgument('full_clone', 1);
-
-			const fields = host_edit.preprocessFormFields(getFormFields(this.form), true);
-			delete fields.sid;
-
-			post(url.getUrl(), fields);
-		},
-
 		delete(hostid, button) {
 			const confirm_text = button.getAttribute('confirm');
 			if (!confirm(confirm_text)) {
@@ -99,9 +170,7 @@
 
 			const curl = new Curl('zabbix.php');
 			curl.setArgument('action', 'host.massdelete');
-			curl.setArgument('<?= CCsrfTokenHelper::CSRF_TOKEN_NAME ?>',
-				<?= json_encode(CCsrfTokenHelper::get('host')) ?>
-			);
+			curl.setArgument(CSRF_TOKEN_NAME, <?= json_encode(CCsrfTokenHelper::get('host')) ?>);
 
 			fetch(curl.getUrl(), {
 				method: 'POST',
