@@ -1,21 +1,16 @@
 <?php declare(strict_types = 0);
 /*
-** Zabbix
-** Copyright (C) 2001-2023 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
@@ -36,6 +31,60 @@
 			this.applied_filter_groupids = applied_filter_groupids;
 
 			this.initFilter();
+
+			document.addEventListener('click', (e) => {
+				if (e.target.classList.contains('js-edit-template')) {
+					this.editTemplate({templateid: e.target.dataset.templateid});
+				}
+				else if (e.target.classList.contains('js-edit-proxy')) {
+					this.editProxy(e.target.dataset.proxyid);
+				}
+				else if (e.target.classList.contains('js-edit-proxy-group')) {
+					this.editProxyGroup(e.target.dataset.proxy_groupid);
+				}
+			});
+		},
+
+		editTemplate(parameters) {
+			const overlay = PopUp('template.edit', parameters, {
+				dialogueid: 'templates-form',
+				dialogue_class: 'modal-popup-large',
+				prevent_navigation: true
+			});
+
+			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => this.reload(e.detail.success));
+		},
+
+		editProxy(proxyid) {
+			const overlay = PopUp('popup.proxy.edit', {proxyid}, {
+				dialogueid: 'proxy_edit',
+				dialogue_class: 'modal-popup-static',
+				prevent_navigation: true
+			});
+
+			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => this.reload(e.detail.success));
+		},
+
+		editProxyGroup(proxy_groupid) {
+			const overlay = PopUp('popup.proxygroup.edit', {proxy_groupid}, {
+				dialogueid: 'proxy-group-edit',
+				dialogue_class: 'modal-popup-static',
+				prevent_navigation: true
+			});
+
+			overlay.$dialogue[0].addEventListener('dialogue.submit', (e) => this.reload(e.detail.success));
+		},
+
+		reload(success) {
+			postMessageOk(success.title);
+
+			if ('messages' in success) {
+				postMessageDetails('success', success.messages);
+			}
+
+			uncheckTableRows('hosts');
+
+			location.href = location.href;
 		},
 
 		initFilter() {
@@ -51,16 +100,27 @@
 				new CTagFilterItem(row);
 			});
 
-			$('#filter_monitored_by').on('change', function() {
-				const filter_monitored_by = $('input[name=filter_monitored_by]:checked').val();
+			$('#filter_monitored_by')
+				.on('change', function() {
+					const filter_monitored_by = $('input[name=filter_monitored_by]:checked').val();
 
-				if (filter_monitored_by == <?= ZBX_MONITORED_BY_PROXY ?>) {
-					$('#filter_proxyids_').multiSelect('enable');
-				}
-				else {
-					$('#filter_proxyids_').multiSelect('disable');
-				}
-			});
+					for (const field of document.querySelectorAll('.js-filter-proxyids')) {
+						field.style.display = filter_monitored_by == <?= ZBX_MONITORED_BY_PROXY ?> ? '' : 'none';
+					}
+
+					$('#filter_proxyids_').multiSelect(
+						filter_monitored_by == <?= ZBX_MONITORED_BY_PROXY ?> ? 'enable' : 'disable'
+					);
+
+					for (const field of document.querySelectorAll('.js-filter-proxy-groupids')) {
+						field.style.display = filter_monitored_by == <?= ZBX_MONITORED_BY_PROXY_GROUP ?> ? '' : 'none';
+					}
+
+					$('#filter_proxy_groupids_').multiSelect(
+						filter_monitored_by == <?= ZBX_MONITORED_BY_PROXY_GROUP ?> ? 'enable' : 'disable'
+					);
+				})
+				.trigger('change');
 		},
 
 		createHost() {
@@ -86,16 +146,17 @@
 				prevent_navigation: true
 			});
 
-			overlay.$dialogue[0].addEventListener('dialogue.create', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.update', this.events.hostSuccess, {once: true});
-			overlay.$dialogue[0].addEventListener('dialogue.delete', this.events.hostDelete, {once: true});
-			overlay.$dialogue[0].addEventListener('overlay.close', () => {
+			overlay.$dialogue[0].addEventListener('dialogue.submit', this.events.elementSuccess, {once: true});
+			overlay.$dialogue[0].addEventListener('dialogue.close', () => {
 				history.replaceState({}, '', original_url);
 			}, {once: true});
 		},
 
 		massDeleteHosts(button) {
-			const confirm_text = button.getAttribute('confirm');
+			const confirm_text = Object.keys(chkbxRange.getSelectedIds()).length > 1
+				? <?= json_encode(_('Delete selected hosts?')) ?>
+				: <?= json_encode(_('Delete selected host?')) ?>;
+
 			if (!confirm(confirm_text)) {
 				return;
 			}
@@ -104,9 +165,7 @@
 
 			const curl = new Curl('zabbix.php');
 			curl.setArgument('action', 'host.massdelete');
-			curl.setArgument('<?= CCsrfTokenHelper::CSRF_TOKEN_NAME ?>',
-				<?= json_encode(CCsrfTokenHelper::get('host')) ?>
-			);
+			curl.setArgument(CSRF_TOKEN_NAME, <?= json_encode(CCsrfTokenHelper::get('host')) ?>);
 
 			fetch(curl.getUrl(), {
 				method: 'POST',
@@ -149,21 +208,7 @@
 		},
 
 		events: {
-			hostSuccess(e) {
-				const data = e.detail;
-
-				if ('success' in data) {
-					postMessageOk(data.success.title);
-
-					if ('messages' in data.success) {
-						postMessageDetails('success', data.success.messages);
-					}
-				}
-
-				location.href = location.href;
-			},
-
-			hostDelete(e) {
+			elementSuccess(e) {
 				const data = e.detail;
 
 				if ('success' in data) {
