@@ -1,61 +1,45 @@
 <?php
 /*
-** Zabbix
-** Copyright (C) 2001-2022 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
 class CTag extends CObject {
 
 	/**
-	 * Encodes the '<', '>', '"' and '&' symbols.
-	 */
-	const ENC_ALL = 1;
-
-	/**
-	 * Encodes all symbols in ENC_ALL except for '&'.
-	 */
-	const ENC_NOAMP = 2;
-
-	/**
-	 * The HTML encoding strategy to use for the contents of the tag.
+	 * The list of tag attributes.
 	 *
-	 * @var int
+	 * @var array
 	 */
-	protected $encStrategy = self::ENC_NOAMP;
+	protected $attributes = [];
 
 	/**
-	 * The HTML encoding strategy for the "value", "name" and "id" attributes.
+	 * The name of the tag.
 	 *
-	 * @var int
+	 * @var string
 	 */
-	protected $attrEncStrategy = self::ENC_ALL;
+	protected $tagname = '';
 
 	/**
-	 * Hint element for the current CTag.
+	 * The type of tag.
 	 *
-	 * @var CSpan
+	 * @var bool
 	 */
-	protected $hint = null;
+	private $paired = false;
 
-	public function __construct($tagname, $paired = false, $body = null) {
+	public function __construct(string $tagname, bool $paired = false, $body = null) {
 		parent::__construct();
 
-		$this->attributes = [];
 		$this->tagname = $tagname;
 		$this->paired = $paired;
 
@@ -64,22 +48,16 @@ class CTag extends CObject {
 		}
 	}
 
-	// do not put new line symbol (\n) before or after html tags, it adds spaces in unwanted places
 	protected function startToString() {
-		$res = '<'.$this->tagname;
+		$attributes = '';
+
 		foreach ($this->attributes as $key => $value) {
-			if ($value === null) {
-				continue;
+			if ($value !== null) {
+				$attributes .= ' '.$key.'="'.htmlspecialchars($value, ENT_QUOTES, 'UTF-8').'"';
 			}
-
-			// a special encoding strategy should be used for the "value", "name" and "id" attributes
-			$strategy = in_array($key, ['value', 'name', 'id'], true) ? $this->attrEncStrategy : $this->encStrategy;
-			$value = $this->encode($value, $strategy);
-			$res .= ' '.$key.'="'.$value.'"';
 		}
-		$res .= '>';
 
-		return $res;
+		return '<'.$this->tagname.$attributes.'>';
 	}
 
 	protected function bodyToString() {
@@ -97,10 +75,6 @@ class CTag extends CObject {
 		$res .= $this->bodyToString();
 		$res .= $this->endToString();
 
-		if ($this->hint !== null) {
-			$res .= $this->hint->toString();
-		}
-
 		if ($destroy) {
 			$this->destroy();
 		}
@@ -109,9 +83,8 @@ class CTag extends CObject {
 	}
 
 	public function addItem($value) {
-		// the string contents of an HTML tag should be properly encoded
 		if (is_string($value)) {
-			$value = $this->encode($value, $this->getEncStrategy());
+			$value = htmlspecialchars($value, ENT_NOQUOTES, 'UTF-8');
 		}
 
 		parent::addItem($value);
@@ -149,7 +122,7 @@ class CTag extends CObject {
 			$value = unpack_object($value);
 		}
 		elseif (is_array($value)) {
-			$value = CHtml::serialize($value);
+			$value = json_encode($value);
 		}
 		$this->attributes[$name] = $value;
 		return $this;
@@ -180,9 +153,7 @@ class CTag extends CObject {
 	 * @return CTag
 	 */
 	public function setHint($text, $span_class = '', $freeze_on_click = true, $styles = '', $delay = null) {
-		$this->hint = (new CDiv($text))
-			->addClass('hint-box')
-			->setAttribute('style', 'display: none;');
+		$this->setAttribute('data-hintbox-contents', (new CTag('', false, $text))->bodyToString());
 
 		$this->setAttribute('data-hintbox', '1');
 
@@ -270,7 +241,7 @@ class CTag extends CObject {
 			$this->attributes['style'] = '';
 		}
 		if (isset($value)) {
-			$this->attributes['style'] .= htmlspecialchars(strval($value));
+			$this->attributes['style'] .= $value;
 		}
 		else {
 			unset($this->attributes['style']);
@@ -283,12 +254,6 @@ class CTag extends CObject {
 		return 1;
 	}
 
-	public function getForm($method = 'post', $action = null, $enctype = null) {
-		$form = (new CForm($method, $action, $enctype))
-			->addItem($this);
-		return $form;
-	}
-
 	public function setTitle($value) {
 		$this->setAttribute('title', $value);
 		return $this;
@@ -314,40 +279,6 @@ class CTag extends CObject {
 		return $this;
 	}
 
-	/**
-	 * Sanitizes a string according to the given strategy before outputting it to the browser.
-	 *
-	 * @param string	$value
-	 * @param int		$strategy
-	 *
-	 * @return string
-	 */
-	protected function encode($value, $strategy = self::ENC_NOAMP) {
-		if ($strategy == self::ENC_NOAMP) {
-			$value = str_replace(['<', '>', '"'], ['&lt;', '&gt;', '&quot;'], $value);
-		}
-		else {
-			$value = CHtml::encode($value);
-		}
-
-		return $value;
-	}
-
-	/**
-	 * @param int $encStrategy
-	 */
-	public function setEncStrategy($encStrategy) {
-		$this->encStrategy = $encStrategy;
-		return $this;
-	}
-
-	/**
-	 * @return int
-	 */
-	public function getEncStrategy() {
-		return $this->encStrategy;
-	}
-
 	/**
 	 * Set or reset element 'aria-required' attribute.
 	 *
