@@ -1,34 +1,22 @@
 /*
-** Zabbix
-** Copyright (C) 2001-2020 Zabbix SIA
+** Copyright (C) 2001-2024 Zabbix SIA
 **
-** This program is free software; you can redistribute it and/or modify
-** it under the terms of the GNU General Public License as published by
-** the Free Software Foundation; either version 2 of the License, or
-** (at your option) any later version.
+** This program is free software: you can redistribute it and/or modify it under the terms of
+** the GNU Affero General Public License as published by the Free Software Foundation, version 3.
 **
-** This program is distributed in the hope that it will be useful,
-** but WITHOUT ANY WARRANTY; without even the implied warranty of
-** MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
-** GNU General Public License for more details.
+** This program is distributed in the hope that it will be useful, but WITHOUT ANY WARRANTY;
+** without even the implied warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.
+** See the GNU Affero General Public License for more details.
 **
-** You should have received a copy of the GNU General Public License
-** along with this program; if not, write to the Free Software
-** Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
+** You should have received a copy of the GNU Affero General Public License along with this program.
+** If not, see <https://www.gnu.org/licenses/>.
 **/
 
 
 (function($) {
 	'use strict';
 
-	function setDisabled(e) {
-		if ($(this)[0] !== e.target) {
-			return;
-		}
-
-		var obj = e.data;
-
-		obj.options.disabled = (e.type === 'disable');
+	function updateProperties(obj, $elm) {
 		obj.$hidden.prop('disabled', obj.options.disabled ? true : null);
 		obj.$input
 			.prop('disabled', obj.options.disabled ? true : null)
@@ -38,11 +26,35 @@
 			.prop('disabled', obj.options.disabled ? true : null)
 			.prop('title', obj.options.disabled ? '' : obj.options.hint);
 
-		$(this)
+		$elm
 			.toggleClass('multilineinput-readonly', (obj.options.readonly && !obj.options.disabled))
 			.toggleClass('multilineinput-disabled', obj.options.disabled);
 	}
 
+	function setDisabled(e) {
+		if ($(this)[0] !== e.target) {
+			return;
+		}
+
+		var obj = e.data,
+			$elm = $(this);
+
+		obj.options.disabled = (e.type === 'disable');
+		updateProperties(obj, $elm);
+	}
+
+	function setReadOnly(e) {
+		if ($(this)[0] !== e.target) {
+			return;
+		}
+
+		var obj = e.data,
+			$elm = $(this);
+
+		obj.options.readonly = (e.type === 'readonly');
+		updateProperties(obj, $elm);
+	}
+
 	function openModal(e) {
 		e.preventDefault();
 
@@ -52,7 +64,7 @@
 			return;
 		}
 
-		function updateSymbolsRemaining(count) {
+		function updateCharCount(count) {
 			$('span', $footer).text(count);
 		}
 
@@ -90,23 +102,30 @@
 			$textarea.css('margin-left', $line_numbers.outerWidth());
 		}
 
-		var height_offset = 190,
+		var height_offset = 220,
 			$content = $('<div>', {class: 'multilineinput-container'}),
 			monospace_font = obj.options.monospace_font ? ' monospace-font' : '',
 			$textarea = $('<textarea>', {
 				class: 'multilineinput-textarea' + monospace_font,
 				text: obj.$hidden.val(),
-				maxlength: obj.options.maxlength,
 				readonly: obj.options.readonly ? true : null,
-				placeholder: obj.options.placeholder_textarea
+				placeholder: obj.options.placeholder_textarea,
+				spellcheck: false
 			}).attr('wrap', 'off'),
 			$line_numbers = $('<ul>', {class: 'multilineinput-line-numbers' + monospace_font}).append('<li>'),
-			$footer = $('<div>', {class: 'multilineinput-symbols-remaining'})
-				.html(sprintf(t('S_N_SYMBOLS_REMAINING'), '<span>0</span>'));
+			$footer = $('<div>', {class: 'multilineinput-char-count'});
+
+		if ('maxlength' in obj.options) {
+			$textarea.attr('maxlength', obj.options.maxlength);
+			$footer.html(sprintf(t('S_N_CHAR_COUNT_REMAINING'), '<span>0</span>'));
+		}
+		else {
+			$footer.html(sprintf(t('S_N_CHAR_COUNT'), '<span>0</span>'));
+		}
 
 		overlayDialogue({
 			'title': obj.options.title,
-			'class': 'multilineinput-modal',
+			'class': 'modal-popup multilineinput-modal',
 			'content': $content,
 			'footer': $footer,
 			'buttons': [
@@ -148,7 +167,9 @@
 		$textarea
 			.on('change contextmenu keydown keyup paste scroll', function() {
 				var value = $(this).val();
-				updateSymbolsRemaining($(this).attr('maxlength') - value.length);
+
+				updateCharCount(('maxlength' in obj.options) ? obj.options.maxlength - value.length : value.length);
+
 				if (obj.options.line_numbers) {
 					updateLineNumbers(value.split("\n").length);
 				}
@@ -171,7 +192,6 @@
 							placeholder_textarea: '',
 							label_before: '',
 							label_after: '',
-							maxlength: 255,
 							rows: 20,
 							grow: 'fixed',
 							readonly: false,
@@ -198,6 +218,7 @@
 					.on('mousedown', obj, openModal);
 
 				obj.$button = $('<button>', {
+					class: ZBX_ICON_PENCIL,
 					type: 'button',
 					title: obj.options.hint,
 					autofocus: obj.options.autofocus || null
@@ -207,6 +228,7 @@
 					.data('multilineInput', obj)
 					.append(obj.$hidden, obj.$input, obj.$button)
 					.on('disable enable', obj, setDisabled)
+					.on('readonly readwrite', obj, setReadOnly)
 					.trigger(obj.options.disabled ? 'disable' : 'enable');
 
 				methods.value.call($this, obj.options.value);
@@ -244,7 +266,17 @@
 		enable: function() {
 			return this.each(function() {
 				$(this).trigger('enable');
-			})
+			});
+		},
+		setReadOnly: function() {
+			return this.each(function() {
+				$(this).trigger('readonly');
+			});
+		},
+		unsetReadOnly: function() {
+			return this.each(function() {
+				$(this).trigger('readwrite');
+			});
 		},
 		destroy: function() {}
 	};
